"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _jsYaml = _interopRequireDefault(require("js-yaml"));

var _config = _interopRequireDefault(require("../../config/config"));

var _utils = require("../utils");

var _common = require("./common");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  DEFAULT_OUT_DIR_PATH
} = (0, _config.default)(process.env.NODE_ENV);

const jsonToYaml = jsonDataString => {
  const jsonObj = JSON.parse(jsonDataString);

  const yamlString = _jsYaml.default.safeDump(jsonObj);

  console.log(yamlString);
};

const jsonToYamlFromFile = async (jsonFilePath, filename, dirPath) => {
  try {
    const jsonObj = await _utils.dataControl.read({
      path: jsonFilePath
    });
    const fileExtension = 'yml';
    const outFileName = filename || `${jsonFilePath.split('/').pop().split('.').shift()}.${fileExtension}`;
    const outDirPath = dirPath || DEFAULT_OUT_DIR_PATH;
    const path = `${outDirPath}/${outFileName}`;

    if (!(await _utils.dataControl.isDirExisted({
      dirPath: outDirPath
    }))) {
      throw new Error(`Not such a directory: '${outDirPath}'`);
    }

    await _utils.dataControl.write(jsonObj, {
      path,
      fileExtension
    });
    console.log(`The converted YAML file was exported to: '${path}'`);
  } catch (error) {
    console.error(`ERROR: ${error}`);
  }
};

const yamlToJson = yamlDataString => {
  const yamlString = yamlDataString.split('\\n').join('\n');

  const jsonString = _jsYaml.default.safeLoad(yamlString);

  (0, _common.prettyLog)(jsonString);
};

const yamlToJsonFromFile = async (yamlFilePath, filename, dirPath) => {
  try {
    const jsonObj = await _utils.dataControl.read({
      path: yamlFilePath
    });
    const fileExtension = 'json';
    const outFileName = filename || `${yamlFilePath.split('/').pop().split('.').shift()}.${fileExtension}`;
    const outDirPath = dirPath || DEFAULT_OUT_DIR_PATH;
    const path = `${outDirPath}/${outFileName}`;

    if (!(await _utils.dataControl.isDirExisted({
      dirPath: outDirPath
    }))) {
      throw new Error(`Not such a directory: '${outDirPath}'`);
    }

    await _utils.dataControl.write(jsonObj, {
      path,
      fileExtension
    });
    console.log(`The converted JSON file was exported to: '${path}'`);
  } catch (error) {
    console.error(`ERROR: ${error}`);
  }
};

var _default = {
  jsonToYaml,
  jsonToYamlFromFile,
  yamlToJson,
  yamlToJsonFromFile
};
exports.default = _default;