"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _util = require("util");

var _fs = _interopRequireDefault(require("fs"));

var _jsYaml = _interopRequireDefault(require("js-yaml"));

var _config = _interopRequireDefault(require("../../config/config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  DIR_PATH,
  TEMPLATE_FILE_PATH
} = (0, _config.default)(process.env.NODE_ENV);

const isDirExisted = ({
  dirPath = DIR_PATH
} = {
  dirPath: DIR_PATH
}) => (0, _util.promisify)(_fs.default.stat)(dirPath).then(() => true).catch(() => false);

const isFileExisted = ({
  path = TEMPLATE_FILE_PATH
} = {
  path: TEMPLATE_FILE_PATH
}) => (0, _util.promisify)(_fs.default.stat)(path).then(() => true).catch(() => false);

const init = async ({
  path = TEMPLATE_FILE_PATH,
  initialValue = {}
} = {
  path: TEMPLATE_FILE_PATH,
  initialValue: {}
}) => {
  if (!(await isDirExisted())) {
    await (0, _util.promisify)(_fs.default.mkdir)(DIR_PATH, {
      recursive: true
    });
  }

  await (0, _util.promisify)(_fs.default.writeFile)(path, JSON.stringify(initialValue), 'utf8');
  return Promise.resolve(initialValue);
};

const read = async ({
  path = TEMPLATE_FILE_PATH
} = {
  path: TEMPLATE_FILE_PATH
}) => {
  const fileExtension = path.split('/').pop().split('.').pop();
  const content = await (0, _util.promisify)(_fs.default.readFile)(path, 'utf8');

  if (fileExtension === 'yaml' || fileExtension === 'yml') {
    return _jsYaml.default.safeLoad(content);
  }

  return JSON.parse(content);
};

const write = async (contentObj, {
  path = TEMPLATE_FILE_PATH,
  fileExtension = 'json'
} = {
  path: TEMPLATE_FILE_PATH,
  fileExtension: 'json'
}) => {
  if (fileExtension === 'txt' || typeof contentObj === 'string') {
    await (0, _util.promisify)(_fs.default.writeFile)(path, contentObj, 'utf8');
  } else if (fileExtension === 'yaml' || fileExtension === 'yml') {
    const contentYaml = _jsYaml.default.safeDump(contentObj);

    await (0, _util.promisify)(_fs.default.writeFile)(path, contentYaml, 'utf8');
  } else {
    await (0, _util.promisify)(_fs.default.writeFile)(path, JSON.stringify(contentObj), 'utf8');
  }

  return Promise.resolve(contentObj);
};

const add = async (templateName, templateObj) => {
  const templatesObj = await read();
  templatesObj[templateName] = templateObj;
  await (0, _util.promisify)(_fs.default.writeFile)(TEMPLATE_FILE_PATH, JSON.stringify(templatesObj), 'utf8');
  return Promise.resolve(templatesObj);
};

const remove = async templateName => {
  const templatesObj = await read();
  delete templatesObj[templateName];
  await (0, _util.promisify)(_fs.default.writeFile)(TEMPLATE_FILE_PATH, JSON.stringify(templatesObj), 'utf8');
  return Promise.resolve(templatesObj);
};

var _default = {
  isDirExisted,
  isFileExisted,
  init,
  read,
  write,
  add,
  remove
};
exports.default = _default;