"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _child_process = require("child_process");

const version = ({
  isYarn = false
} = {
  isYarn: false
}) => new Promise((resolve, reject) => {
  let child;

  if (isYarn) {
    child = (0, _child_process.spawn)('yarn', ['--version']);
    child.stdout.on('data', data => {
      console.log(`${data}`);
    });
    child.stderr.on('data', data => {
      console.log(`${data}`);
    });
    child.on('close', code => {
      if (code === 0) {
        resolve(true);
      } else {
        reject(new Error("Faild to execute the command: 'yarn --version'"));
      }
    });
  } else {
    child = (0, _child_process.spawn)('npm', ['--version']);
    child.stdout.on('data', data => {
      console.log(`${data}`);
    });
    child.stderr.on('data', data => {
      console.log(`${data}`);
    });
    child.on('close', code => {
      if (code === 0) {
        resolve(true);
      } else {
        reject(new Error("Faild to execute the command: 'npm --version'"));
      }
    });
  }
});

const init = ({
  isYarn = false
} = {
  isYarn: false
}) => new Promise((resolve, reject) => {
  let child;

  if (isYarn) {
    child = (0, _child_process.spawn)('yarn', ['init', '-y']);
    child.stdout.on('data', data => {
      console.log(`${data}`);
    });
    child.stderr.on('data', data => {
      console.log(`${data}`);
    });
    child.on('close', code => {
      if (code === 0) {
        resolve(true);
      } else {
        reject(new Error("Faild to execute the command: 'yarn init -y'"));
      }
    });
  } else {
    child = (0, _child_process.spawn)('npm', ['init', '-y']);
    child.stdout.on('data', data => {
      console.log(`${data}`);
    });
    child.stderr.on('data', data => {
      console.log(`${data}`);
    });
    child.on('close', code => {
      if (code === 0) {
        resolve(true);
      } else {
        reject(new Error("Faild to execute the command: 'npm init -y'"));
      }
    });
  }
});

const add = (moduleName, {
  isDev = false,
  isYarn = false
} = {
  isDev: false,
  isYarn: false
}) => new Promise((resolve, reject) => {
  let child;

  if (isYarn) {
    child = isDev ? (0, _child_process.spawn)('yarn', ['add', '--dev', moduleName]) : (0, _child_process.spawn)('yarn', ['add', moduleName]);
    child.stdout.on('data', data => {
      console.log(`${data}`);
    });
    child.stderr.on('data', data => {
      console.log(`${data}`);
    });
    child.on('close', code => {
      if (code === 0) {
        resolve(true);
      } else {
        reject(new Error("Faild to execute the command: 'yarn add'"));
      }
    });
  } else {
    child = isDev ? (0, _child_process.spawn)('npm', ['install', '--save-dev', moduleName]) : (0, _child_process.spawn)('npm', ['install', '--save', moduleName]);
    child.stdout.on('data', data => {
      console.log(`${data}`);
    });
    child.stderr.on('data', data => {
      console.log(`${data}`);
    });
    child.on('close', code => {
      if (code === 0) {
        resolve(true);
      } else {
        reject(new Error("Faild to execute the command: 'npm install'"));
      }
    });
  }
});

const remove = (moduleName, {
  isYarn = false
} = {
  isYarn: false
}) => new Promise((resolve, reject) => {
  let child;

  if (isYarn) {
    child = (0, _child_process.spawn)('yarn', ['remove', moduleName]);
    child.stdout.on('data', data => {
      console.log(`${data}`);
    });
    child.stderr.on('data', data => {
      console.log(`${data}`);
    });
    child.on('close', code => {
      if (code === 0) {
        resolve(true);
      } else {
        reject(new Error("Faild to execute the command: 'yarn remove'"));
      }
    });
  } else {
    child = (0, _child_process.spawn)('npm', ['uninstall', moduleName]);
    child.stdout.on('data', data => {
      console.log(`${data}`);
    });
    child.stderr.on('data', data => {
      console.log(`${data}`);
    });
    child.on('close', code => {
      if (code === 0) {
        resolve(true);
      } else {
        reject(new Error("Faild to execute the command: 'npm uninstall'"));
      }
    });
  }
});

var _default = {
  version,
  init,
  add,
  remove
};
exports.default = _default;